==> qtjambi-sql-6.4.3-sources.jar: io/qt/sql/QSqlDriverPlugin.java <==
package io.qt.sql;


/**
 * <p>Abstract base for custom QSqlDriver plugins</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qsqldriverplugin.html">QSqlDriverPlugin</a></p>
 */
public abstract class QSqlDriverPlugin extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSqlDriverPlugin.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QSqlDriverPlugin {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.sql.QSqlDriver create(java.lang.String key){
            return create_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), key);
        }
        @io.qt.QtUninvokable
        private native io.qt.sql.QSqlDriver create_native_cref_QString(long __this__nativeId, java.lang.String key);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QSqlDriverPlugin(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QSqlDriverPlugin() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqldriverplugin.html#QSqlDriverPlugin">QSqlDriverPlugin::QSqlDriverPlugin(QObject*)</a></p>
     */
    public QSqlDriverPlugin(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSqlDriverPlugin instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqldriverplugin.html#create">QSqlDriverPlugin::create(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract io.qt.sql.QSqlDriver create(java.lang.String key);
    
    @io.qt.QtUninvokable
    private native io.qt.sql.QSqlDriver create_native_cref_QString(long __this__nativeId, java.lang.String key);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSqlDriverPlugin(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSqlDriverPlugin(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSqlDriverPlugin instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-sql-6.4.4-sources.jar: io/qt/sql/QSqlDriverPlugin.java <==
package io.qt.sql;

import io.qt.*;


/**
 * <p>Abstract base for custom QSqlDriver plugins</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qsqldriverplugin.html">QSqlDriverPlugin</a></p>
 */
public abstract class QSqlDriverPlugin extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSqlDriverPlugin.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QSqlDriverPlugin {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public io.qt.sql.@Nullable QSqlDriver create(java.lang.@NonNull String key){
            return create_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), key);
        }
        @QtUninvokable
        private native io.qt.sql.QSqlDriver create_native_cref_QString(long __this__nativeId, java.lang.String key);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QSqlDriverPlugin() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqldriverplugin.html#QSqlDriverPlugin">QSqlDriverPlugin::QSqlDriverPlugin(QObject*)</a></p>
     */
    public QSqlDriverPlugin(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSqlDriverPlugin instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsqldriverplugin.html#create">QSqlDriverPlugin::create(QString)</a></p>
     */
    @QtUninvokable
    public abstract io.qt.sql.@Nullable QSqlDriver create(java.lang.@NonNull String key);
    
    @QtUninvokable
    private native io.qt.sql.QSqlDriver create_native_cref_QString(long __this__nativeId, java.lang.String key);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QSqlDriverPlugin(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QSqlDriverPlugin(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QSqlDriverPlugin instance, QDeclarativeConstructor constructor);
    
}
